Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(1841)

Unified Diff: chrome/browser/policy/app_pack_updater.h

Issue 10692168: Moved ExternalExtensionLoaders/Providers into extensions namespace (Closed) Base URL: http://git.chromium.org/chromium/src.git@master
Patch Set: Created 8 years, 5 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: chrome/browser/policy/app_pack_updater.h
diff --git a/chrome/browser/policy/app_pack_updater.h b/chrome/browser/policy/app_pack_updater.h
index b614ff8f02d3298fd2b0fd87cd6ef8e52bdc1e16..fe7f32eae192857e7698ca516283aa0f21d8b8c8 100644
--- a/chrome/browser/policy/app_pack_updater.h
+++ b/chrome/browser/policy/app_pack_updater.h
@@ -22,12 +22,12 @@
#include "net/base/network_change_notifier.h"
class CrxInstaller;
-class ExternalExtensionLoader;
class FilePath;
class GURL;
namespace extensions {
class ExtensionDownloader;
+class ExternalLoader;
}
namespace net {
@@ -40,7 +40,7 @@ class Location;
namespace policy {
-class AppPackExternalExtensionLoader;
+class AppPackExternalLoader;
class BrowserPolicyConnector;
// The AppPackUpdater manages a set of extensions that are configured via a
@@ -63,10 +63,10 @@ class AppPackUpdater : public CloudPolicySubsystem::Observer,
BrowserPolicyConnector* connector);
virtual ~AppPackUpdater();
- // Creates an ExternalExtensionLoader that will load the crx files downloaded
- // by the AppPackUpdater. This can be called at most once, and the caller
- // owns the returned value.
- ExternalExtensionLoader* CreateExternalExtensionLoader();
+ // Creates an extensions::ExternalLoader that will load the crx files
+ // downloaded by the AppPackUpdater. This can be called at most once, and the
+ // caller owns the returned value.
+ extensions::ExternalLoader* CreateExternalLoader();
// |callback| will be invoked whenever the screen saver extension's path
// changes. It will be invoked "soon" after this call if a valid path already
@@ -222,7 +222,7 @@ class AppPackUpdater : public CloudPolicySubsystem::Observer,
// The extension loader wires the AppPackUpdater to the extensions system, and
// makes it install the currently cached extensions.
bool created_extension_loader_;
- base::WeakPtr<AppPackExternalExtensionLoader> extension_loader_;
+ base::WeakPtr<AppPackExternalLoader> extension_loader_;
// Used to download the extensions configured via policy, and to check for
// updates.

Powered by Google App Engine
This is Rietveld 408576698